from pymongo import MongoClient
import datetime


class Mango:
    def __init__(self, connect):
        try:
            self.client = MongoClient(connect)
            self.users = self.client['dns']['users']
            self.keys = self.client['dns']['keys']
        except ConnectionError:
            print('MongoDB connection error')

    def google_check_sso_uuid(self, uuid):  # checks if uuid exist in any document
        found = self.users.find_one({"sso.google.profile.sub": uuid})

        if found is None:  # None if nothing found
            return {"error": True, "reason": "User not found"}
        else:
            return {"error": False}

    def google_update_lastlogin(self, uuid):  # replaces lastlogin with current time for given user
        found = self.users.find_one({"sso.google.profile.sub": uuid})

        if found is None:
            return {"error": True, "reason": "User not found"}

        found['sso']['google']['lastlogin'] = datetime.datetime.utcnow()

        self.users.replace_one({"sso.google.profile.sub": uuid}, found)

        return {"error": False}

    def google_update_profile(self, profile):  # overwrites user profile with the one that google has given
        found = self.users.find_one({"sso.google.profile.sub": profile['sub']})

        found['sso']['google']['profile'] = profile

        self.users.replace_one({"sso.google.profile.sub": profile['sub']}, found)

        return {"error": False}

    def google_get_profile(self, uuid):  # returns google profile as stored in db for a given user
        found = self.users.find_one(({"sso.google.profile.sub": uuid}))
        return found['sso']['google']['profile']

    def google_get_lastlogin(self, uuid):  # returns lastlogin in pretty format for given user
        found = self.users.find_one(({"sso.google.profile.sub": uuid}))
        return found['sso']['google']['lastlogin'].strftime('%A %d-%m-%Y, %H:%M:%S')

    def google_add_new_sub(self, uuid):  # adds new document in db with only the sub for a given uuid
        self.users.insert_one({'sso':{'google':{'profile':{"sub": str(uuid)}}}})

    def google_overwrite_jwt(self, uuid, jwt):  # overwrite jwt in db for given user
        found = self.users.find_one({"sso.google.profile.sub": uuid})

        found['sso']['google']['jwt'] = jwt
        self.users.replace_one({"sso.google.profile.sub": uuid}, found)

    def google_get_jwt(self, uuid):  # return jwt as stored in db for given user
        found = self.users.find_one({"sso.google.profile.sub": uuid})
        return found['sso']['google']['jwt']

    def check_api_key(self, key):  # True or False if api key exists in api keys db
        if self.keys.find_one({"key": key}):
            return True
        return False
