class GoogleOID:
    def __init__(self):
        import requests
        import jwt
        import os
        client_secret = os.environ.get('OPENID_SECRET')  # change this to your secret if running manually

        if client_secret is None:  # if environ not set
            print('No OPENID_SECRET environ')
            exit(1)

        self.jwt = jwt
        self.requests = requests

        self.settings = {'client_id': '954325872153-1v466clrtgg6h4ptt2ne5pgpb9mhilr5.apps.googleusercontent.com',
                         'client_secret': client_secret,
                         'callback_uri': 'https://dnsgui.mashallah.nl/login/gcp/callback',
                         'key_server': 'https://www.googleapis.com/oauth2/v3/certs'}  # global oid settings

    def settings(self):  # make it so that the settings variable is callable
        return self.settings

    def get_token_from_code(self, code):  # get usable api token from oauth code
        data = {'grant_type': 'authorization_code',
                'client_id': self.settings['client_id'],
                'client_secret': self.settings['client_secret'],
                'redirect_uri': self.settings['callback_uri'],
                'code': code}

        r = self.requests.post('https://oauth2.googleapis.com/token', data=data)  # exchange code for token

        if r.status_code != 200:  # if not successful
            return {'error': True, 'reason': f'Could not exchange code for access key {r.status_code}'}

        return {'error': False, 'data': r.json()}

    def get_profile_information(self, token):  # get google profile with token
        headers = {'Authorization': f'Bearer {token}'}

        r = self.requests.get('https://openidconnect.googleapis.com/v1/userinfo', headers=headers)

        if r.status_code != 200:  # if not successful
            return {'error': True, 'reason': f'Could not get profile info {r.status_code}'}

        return {'error': False, 'profile': r.json()}

    def check_jwt(self, bearer):  # check if jwt is signed by google and valid
        jwks_client = self.jwt.PyJWKClient(self.settings['key_server'])  # setup jwks client with keyserver
        signing_key = jwks_client.get_signing_key_from_jwt(bearer).key  # extract signing key from jwt

        try:  # fails if jwt is not valid eg. not signed by google, expired, wrong application
            decoded = self.jwt.decode(bearer, signing_key, algorithms=["RS256"], audience=self.settings['client_id'])
        except self.jwt.exceptions.DecodeError:  # catch generic error
            return {'error': True, 'reason': 'Error decoding JWT'}

        return {'error': False, 'data': decoded}
